#!/usr/bin/env python3

import subprocess
import platform


class DockerHelper:
    def __init__(self):
        self.docker_address = ""

    def inspect_docker_bridge(self) -> bool:
        try:
            # Returns the running config of the docker bridge in json format
            command = "docker network inspect bridge"
            result = subprocess.check_output(command, timeout=10, universal_newlines=True, shell=True)
        except subprocess.TimeoutExpired:
            return  False
        except subprocess.CalledProcessError:
            return  False

        for line in result.strip().split("\n"):
            if 'Gateway' in line:
                field = line.split()
                # Expecting "Gateway": "192.168.43.1"
                if len(field) < 2 or len(field[1]) < 2:
                    print("\ndockerhelper: Unexpected output format of 'docker network inspect bridge' command.\n")
                    return False
                # Return the gateway ip address
                self.docker_address = field[1][1:field[1].rfind('"')]
                return True
        print("\ndockerhelper: Failed to obtain docker bridge address.\n")
        return False

    def get_docker_bridge(self) -> str:
        if self.docker_address == "":
            if platform.system() == "Linux":
                if not self.inspect_docker_bridge():
                    return ""
            else:
                self.docker_address = "1.2.3.4"

        return self.docker_address

